export const GENDER = {
    M: 'M',
    F: 'F',
};

export const COUNTRY_CODE = {
    FR: 'FR',
    ES: 'ES'
};

export const STATUS = {
    COVERED: 'COVERED',
    SUSPENDED: 'SUSPENDED',
    CLOSED: 'CLOSED',
    PENDING: 'PENDING',
    UNPAID: 'UNPAID'
};

const beneficiary = function (sequelize, Sequelize) {
    const beneficiary = sequelize.define('beneficiary',
        {
            id: {
                primaryKey: true,
                type: Sequelize.UUID,
                defaultValue: Sequelize.UUIDV4
            },
            rk_clientId: {
                type: Sequelize.STRING,
                allowNull: true
            },
            gender: {
                type: Sequelize.ENUM,
                values: Object.values(GENDER),
                defaultValue: 'M',
                validate: {
                    isIn: [Object.values(GENDER)],
                }
            },
            socialWelfareNumber: {
                type: Sequelize.STRING,
                allowNull: true
            },
            firstname: {
                type: Sequelize.STRING,
                notEmpty: true
            },
            lastname: {
                type: Sequelize.STRING,
                notEmpty: true
            },
            birthdate: {
                type: Sequelize.DATE,
                allowNull: true
            },
            placeOfBirth: {
                type: Sequelize.STRING,
                allowNull: true
            },
            address: {
                type: Sequelize.STRING,
                notEmpty: true
            },
            addressLine2: {
                type: Sequelize.STRING,
                allowNull: true
            },
            zipcode: {
                type: Sequelize.STRING,
                notEmpty: true
            },
            city: {
                type: Sequelize.STRING,
                notEmpty: true
            },
            countryCode: {
                type: Sequelize.ENUM,
                values: Object.values(COUNTRY_CODE),
                defaultValue: 'FR',
                validate: {
                    isIn: [Object.values(COUNTRY_CODE)],
                }
            },
            status: {
                type: Sequelize.ENUM,
                values: Object.values(STATUS),
                defaultValue: 'PENDING',
                validate: {
                    isIn: [Object.values(STATUS)],
                }
            },
            ibanHolderName: {
                type: Sequelize.STRING,
                allowNull: true
            },
            iban: {
                type: Sequelize.STRING,
                allowNull: true
            },
            bic: {
                type: Sequelize.STRING,
                allowNull: true
            },
            isMasterAccount: {
                type: Sequelize.BOOLEAN,
                defaultValue: false
            },
            privacy: {
                type: Sequelize.BOOLEAN,
                defaultValue: false
            },
            contractAnniversaryDate: {
                type: Sequelize.DATE,
                allowNull: true
            },
            seniority: {
                type: Sequelize.INTEGER,
                defaultValue: 0
            },
            boostCounter: {
                type: Sequelize.INTEGER,
                defaultValue: 0
            },
            picture: {
                type: Sequelize.STRING,
                defaultValue: "avatar"
            },
            lastDowngradeDate: {
                type: Sequelize.DATE,
            }
            // fk_planListId
            // fk_userId > parent (master account)
        });

    return beneficiary;
};

export default beneficiary;
