import bcrypt from 'bcrypt';

export const GENDER = {
    M: 'M',
    F: 'F',
};

export const RIGHTS = {
    ALL: 'ALL',
    READ: 'READ',
    NONE: 'NONE'
};

export const STATUS = {
    PENDING: 'PENDING',
    NOT_ACTIVATED: 'NOT_ACTIVATED',
    ACTIVATED: 'ACTIVATED',
    LOCKED: 'LOCKED',
    CLOSED: 'CLOSED'
};


const user = function (sequelize, Sequelize) {
    const user = sequelize.define('user',
        {
            id: {
                primaryKey: true,
                type: Sequelize.UUID,
                defaultValue: Sequelize.UUIDV4
            },
            rk_pspCustomerId: {
                type: Sequelize.STRING
            },
            gender: {
                type: Sequelize.ENUM,
                values: Object.values(GENDER),
                defaultValue: 'M',
                validate: {
                    isIn: [Object.values(GENDER)],
                }
            },
            firstname: {
                type: Sequelize.STRING,
                notEmpty: true
            },
            lastname: {
                type: Sequelize.STRING,
                notEmpty: true
            },
            email: {
                type: Sequelize.STRING,
                validate: {
                    isEmail: true
                },
                allowNull: false
            },
            phone: {
                type: Sequelize.STRING,
                notEmpty: true,
                unique: {
                    args: true,
                    msg: 'Phone number already used!'
                }
            },
            status: {
                type: Sequelize.ENUM,
                values: Object.values(STATUS),
                defaultValue: 'PENDING',
                validate: {
                    isIn: [Object.values(STATUS)],
                }
            },
            isDutyAdviceAuthorized: {
                type: Sequelize.BOOLEAN,
                defaultValue: false
            },
            hasAcceptedGCU: {
                type: Sequelize.BOOLEAN,
                defaultValue: false
            },
            rights: {
                type: Sequelize.ENUM,
                values: Object.values(RIGHTS),
                defaultValue: 'NONE',
                validate: {
                    isIn: [Object.values(RIGHTS)],
                }
            }
        });


    return user;
};

export default user;
